@@ -32,7 +32,7 @@ static void g_mime_stream_file_init (GMimeStreamFile *stream, GMimeStreamFileCla
 static void g_mime_stream_file_finalize (GObject *object);
 
 static ssize_t stream_read (GMimeStream *stream, char *buf, size_t len);
-static ssize_t stream_write (GMimeStream *stream, char *buf, size_t len);
+static ssize_t stream_write (GMimeStream *stream, const char *buf, size_t len);
 static int stream_flush (GMimeStream *stream);
 static int stream_close (GMimeStream *stream);
 static gboolean stream_eos (GMimeStream *stream);
@@ -136,7 +136,7 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 }
 
 static ssize_t
-stream_write (GMimeStream *stream, char *buf, size_t len)
+stream_write (GMimeStream *stream, const char *buf, size_t len)
 {
 	GMimeStreamFile *fstream = (GMimeStreamFile *) stream;
 	ssize_t nwritten;
